@@ -2,7 +2,8 @@ from urlparse import urljoin
 
 import requests
 import convertible
-
+from IPy import IP
+from syncloud.app import logger
 from syncloud.insider.config import Service
 
 
@@ -27,6 +28,7 @@ class Dns:
         self.domain_config = domain_config
         self.service_config = service_config
         self.port_mapper = port_mapper
+        self.logger = logger.get_logger('dns')
 
     def check_http_error(self, response):
         if not response.status_code == 200:
@@ -66,7 +68,7 @@ class Dns:
 
     def full_name(self):
         domain_config = self.domain_config.load()
-        return 'device.{}.{}'.format(domain_config.user_domain, self.main_domain_name)
+        return '{0}.{1}'.format(domain_config.user_domain, self.main_domain_name)
 
     def user_domain(self):
         return self.domain_config.load().user_domain
@@ -82,13 +84,17 @@ class Dns:
         self.port_mapper.sync()
 
         services = self.service_config.load()
-        mappings = self.port_mapper.list()
         domain = self.domain_config.load()
-        external_ip = self.port_mapper.external_ip()
         if not domain:
             raise Exception("no token saved, need to call set_dns or get_dns_token first")
+
+        external_ip = self.port_mapper.external_ip()
         if not external_ip:
-            raise Exception("unable to get external ip")
+            self.logger.warn("unable to get external ip")
+        else:
+            if IP(external_ip).iptype() != 'PUBLIC':
+                external_ip = None
+                self.logger.warn("external ip is not public")
 
         for service in services:
             mapping = self.port_mapper.get(service.port)
@@ -97,7 +103,12 @@ class Dns:
             else:
                 services.remove(service)
 
-        data = {'token': domain.update_token, 'ip': external_ip, 'services': services}
+        data = {'token': domain.update_token, 'services': services}
+        if external_ip:
+            data['ip'] = external_ip
+        else:
+            self.logger.warn("will try server side client ip detection")
+
 
         url = urljoin(self.api_url, "/domain/update")
 
